/*
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A 
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR 
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION 
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE 
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO 
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO 
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE 
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 */

/*****************************************************************************/
/**
*
* @Project Audio_Demo
* 
* This project contains an audio demo example to show some of the Genesys onboard LM4550 
* AC'97 audio codec features. The application uses the ac97_if_00 custom core. The ac97_if_00 
* core is a PLB slave and an AC'97 interface with 48KHz sample rate only.
* Connect audio source such as music player or computer to the LINE IN input.
* Connect a microphone to the MIC input and headphones or speakers to the HP_OUT output.
* SW0 changes between LINE IN or MIC input (SW0 = 0: MIC, SW0 = 1: LINE IN). Toggling SW0
* also unmutes the selected input
* Pressing then releasing the following buttons
* LEFT button: Generates a 1KHz square-wave signal for 0.5S on the left channel.
* RIGHT button: Generates a 1KHz square-wave signal for 0.5S on the right channel.
* CENTER button: Generates a 1KHz square-wave signal for 0.5S on both channels.
* UP button: Records for about 5 S audio from the source selected by SW0
* DOWN button: Plays back the recorded data. While recording and playing a progress bar
* is shown on the LEDs.
* 
* By default the selected input is unmuted, therefore either signal from the microphone
* or from the LINE_OUT input can be heared in the headphones. During square-wave 
* generation the selected input is muted then after the square-wave ends is unmuted
* again.
* 
* After recording or playback the selected input is muted. Unmuting can be done by
* toggling twice SW0
* 
* The "ac97_if_00.c" file contains the functions needed to access the AC97 codec internal registers and
* the PCM IN and OUT data
*
* @note
* DDR2 memory must be present for recording and playback to work
* 
******************************************************************************/

#define AC97_CODEC_BASEADDR XPAR_AC97_IF_00_0_BASEADDR

#define MEM_ADDRESS XPAR_DDR2_SDRAM_MPMC_BASEADDR + 0x4000000
#define RECORDING_TIME 5
#define SAMPLE_RATE_HZ 48000
#define NUM_CHANNELS 2
//Number of samples to record: RECORDING_TIME * SAMPLE_RATE_HZ * NUM_CHANNELS
#define NUM_SAMPLES_TO_RECORD RECORDING_TIME * SAMPLE_RATE_HZ * NUM_CHANNELS


#include <stdio.h>
#include "xparameters.h"
#include "xenv_standalone.h"
#include "xbasic_types.h"
#include "xgpio.h"
#include "xuartns550_l.h"
#include "lcd.h"
#include "xintc.h"
#include "ac97_if_00.h"



/******************************************************************************
 * 
 * 	Variable declaration
 * 
 * ***************************************************************************/

//set to 1 in order to display debug messages
unsigned char verbose=0;

/******************************************************************************
 * 
 * 	Function prototypes
 * 
 * ***************************************************************************/

void LCDInitAndPrint (char * First_Line, char * Second_Line);


int main()
{

Xuint32 btn_data;
Xuint32 sw_data, sw_data_pre;
Xuint32 i;
Xuint32 LED_Data=1;

XStatus Status;
Xuint32 Count_Samples;

Xuint32 * ADDRESS;

   /* Initialize RS232_Uart_0 - Set baudrate and number of stop bits */
   XUartNs550_SetBaud(XPAR_RS232_UART_0_BASEADDR, XPAR_XUARTNS550_CLOCK_HZ, 9600);
   XUartNs550_mSetLineControlReg(XPAR_RS232_UART_0_BASEADDR, XUN_LCR_8_DATA_BITS);


   XCACHE_ENABLE_ICACHE();
   XCACHE_ENABLE_DCACHE();

	//set LEDs as output
	XIo_Out32(XPAR_LEDS_8BIT_BASEADDR + 0x04 , 0x00);

   //initialize LCD
    LCDInitAndPrint ((char *) &"--   GENESYS  --", (char *) &"-  Audio Demo  -");
  	
   //wait until the AC'97 link becomes ready
   while (!(AC97_Link_Is_Ready (AC97_CODEC_BASEADDR)));
   //set TAG and ID to 0x7C in order to access the AC'97 codec internal registers
   AC97_Set_Tag_And_Id (AC97_CODEC_BASEADDR, 0x7C);	

   //unmute the Master, Output and Headphone channels
   Status = AC97_Unmute (AC97_CODEC_BASEADDR, AC97_MASTER_VOLUME_OFFSET);
   Status = AC97_Unmute (AC97_CODEC_BASEADDR, AC97_HEADPHONE_VOLUME_OFFSET);
   Status = AC97_Unmute (AC97_CODEC_BASEADDR, AC97_PCM_OUT_VOLUME_OFFSET);
   
   //set the volume on these channels
   Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_MASTER_VOLUME_OFFSET, 
   						     BOTH_CHANNELS, VOLUME_MAX);
   Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_HEADPHONE_VOLUME_OFFSET, 
   						     BOTH_CHANNELS, VOLUME_MAX);
   Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_PCM_OUT_VOLUME_OFFSET, 
   						     BOTH_CHANNELS, VOLUME_MAX);	

    xil_printf ("\r\n\r\nGenesys Audio Demo\r\n");
    xil_printf("\r\nConnect audio source such as music player or computer to the LINE IN input");
    xil_printf("\r\nConnect a microphone to the MIC input and headphones or speakers to the HP_OUT output ");
    xil_printf("\r\nSW0: changes between LINE IN or MIC input (SW0 = 0: MIC, SW0 = 1: LINE IN");
    xil_printf("\r\nPressing then releasing the following buttons:");
    xil_printf("\r\nLEFT button: Generates a 1KHz square-wave signal for 0.5S on the left channel");
    xil_printf("\r\nRIGHT button: Generates a 1KHz square-wave signal for 0.5S on the right channel");
    xil_printf("\r\nCENTER button: Generates a 1KHz square-wave signal for 0.5S on both channels");
    xil_printf("\r\nUP button: Records for about 5 S audio from the source selected by SW0");
    xil_printf("\r\nDOWN button: Plays back the recorded data\r\n");

	//set the volume on the LINE IN input
	Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET, 
   						     BOTH_CHANNELS, VOLUME_MAX);
   	//set the volume on the MIC input and allow 20db boost
	Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET, 
   						     BOTH_CHANNELS, (1 << boost20dB) | VOLUME_MAX);

	//set record gain
	Status = AC97_Set_Volume (AC97_CODEC_BASEADDR, AC97_RECORD_GAIN_OFFSET, 
   						     BOTH_CHANNELS, GAIN_MIN);
 
   //set 3D and unselect loopback
    Status = AC97_WriteReg (AC97_CODEC_BASEADDR, 0x20, 0x2000);

    //check the status of SW0 and select the corresponding input
	sw_data = XIo_In32(XPAR_DIP_SWITCHES_8BIT_BASEADDR);
	if (sw_data & 0x01)
	{
   	   Status = AC97_Select_Input (AC97_CODEC_BASEADDR, BOTH_CHANNELS, AC97_LINE_IN_SELECT);
   	   Status = AC97_Unmute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
   	   Status = AC97_Mute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
   	   xil_printf("\r\nLINE In Selected");
   	   LCDClear();
   	   LCDPrintString   ("-  Audio Demo  -",
    			 	     "Line In Selected");  
	}
	else
	{
   	  Status = AC97_Select_Input (AC97_CODEC_BASEADDR, BOTH_CHANNELS, AC97_MIC_SELECT);
   	  Status = AC97_Unmute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
   	  Status = AC97_Mute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
   	  xil_printf("\r\nMIC Selected");
   	  LCDClear();
   	  LCDPrintString   ("-  Audio Demo  -",
    			 	    "  MIC Selected  ");  
	}

	//initialize sw_data_pre to see if any change occured
	sw_data_pre = sw_data;
		
	//infinite loop, poll switch and button change
    while (1)
    {
		 sw_data = XIo_In32(XPAR_DIP_SWITCHES_8BIT_BASEADDR);	
		 btn_data = XIo_In32(XPAR_PUSH_BUTTONS_7BIT_BASEADDR);
	 
		 if ((sw_data ^ sw_data_pre) & 0x01)//SW0 has changed, therefore select the other input
		 {
			if (sw_data & 0x01)
			{
  	  		   AC97_Select_Input (AC97_CODEC_BASEADDR, BOTH_CHANNELS, AC97_LINE_IN_SELECT);
   	           AC97_Unmute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
   	           AC97_Mute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
		   	   xil_printf("\r\nLINE In Selected");
		   	   LCDClear();
		   	   LCDPrintString   ("-  Audio Demo  -",
		    			 	     "Line In Selected");  
			}
			else
			{
              AC97_Select_Input (AC97_CODEC_BASEADDR, BOTH_CHANNELS, AC97_MIC_SELECT);
   	          AC97_Unmute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
   	          AC97_Mute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);		   	  
		   	  xil_printf("\r\nMIC Selected");
		   	  LCDClear();
		   	  LCDPrintString   ("-  Audio Demo  -",
		    			 	    "  MIC Selected  ");  
			}	
		}
	
	    //check for button press
	    if (btn_data)
	    {
		 	//determine which button was pressed
		 	for (i=0; i<5; i++)
		 	{
		 		if (btn_data & (1 << i)) break;	
		 	}
		 	//wait until the button is released
		 	while ((XIo_In32(XPAR_PUSH_BUTTONS_7BIT_BASEADDR) & (1<<i)));
		 	btn_data = 0;
		 	switch (i)
		 	{
		 	case 0: //center button was pressed, generate a 1KHz square wave for 0.5S on both channels
		 	GenSquare (AC97_CODEC_BASEADDR, BOTH_CHANNELS, 1000, 500);
		 	break;
	 	
		 	case 1: //left button was pressed, generate a 1KHz square wave for 0.5S on the left channel
		 	GenSquare (AC97_CODEC_BASEADDR, LEFT_CHANNEL, 1000, 500);
		 	break;
		 	
		 	case 3: //right button was pressed, generate a 1KHz square wave for 0.5S on the left channel
		 	GenSquare (AC97_CODEC_BASEADDR, RIGHT_CHANNEL, 1000, 500);
		 	break;
	 	
		    case 4: //UP button was pressed, record for about 5S
			xil_printf("\r\nRecording...");
			LCDClear();
		    LCDPrintString   ("- Recording... -","");
			LED_Data = 1;
			XIo_Out32(XPAR_LEDS_8BIT_BASEADDR, LED_Data);
			//unmute the currently selected input
			 if (sw_data & 0x01) AC97_Unmute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
			 else AC97_Unmute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
			//set TAG and ID to 0x4C in order to send and receive valid frame data to and from
			//the AC'97 audio codec
			Count_Samples = 0;
			ADDRESS = (void *) MEM_ADDRESS;
			//record the samples
			while (Count_Samples < NUM_SAMPLES_TO_RECORD)
			{
		   		Count_Samples = Count_Samples + Read_PCM_Samples (AC97_CODEC_BASEADDR, ADDRESS, 
		   										BOTH_CHANNELS);

		   		//two samples are recorded, increment the current address pointer by two
		   		ADDRESS = ADDRESS +2;
   		 
		   		 //display a progress bar on the LEDs
		   		 if (!(Count_Samples&0xFFFF))
		   		 {
		   			LED_Data = (LED_Data << 1) | 0x01 ;	 	
		   		    XIo_Out32(XPAR_LEDS_8BIT_BASEADDR, LED_Data);
		   		 }
			}
			xil_printf("\r\nRecorded %d samples on two channels", Count_Samples);
			LCDClear();
		    LCDPrintString   ("-   Recording  -",
		    				  "-   Complete   -");
			//mute inputs after recording
			if (sw_data & 0x01) AC97_Mute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
			else AC97_Mute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
			break;
		
			case 2: //DOWN button was pressed, play back the recorded data
			xil_printf("\r\nPlaying...");
			LCDClear();
		    LCDPrintString   ("-  Playing...  -","");
			LED_Data = 1;
			XIo_Out32(XPAR_LEDS_8BIT_BASEADDR, LED_Data);
			//mute the currently selected input
			if (sw_data & 0x01) AC97_Mute (AC97_CODEC_BASEADDR, AC97_LINE_IN_VOLUME_OFFSET);
			else AC97_Mute (AC97_CODEC_BASEADDR, AC97_MIC_VOLUME_OFFSET);
			ADDRESS = (void *)MEM_ADDRESS;			
			Count_Samples = 0;
			//play back the samples
			 while (Count_Samples < NUM_SAMPLES_TO_RECORD)
			{
		   		 //wait for the beginning of a new frame
				Count_Samples = Count_Samples + Write_PCM_Samples (AC97_CODEC_BASEADDR, ADDRESS,
												BOTH_CHANNELS);
		   		//two samples are recorded, increment the current address pointer by two
		   		ADDRESS = ADDRESS +2;
		   		
		   		 //display a progress bar on the LEDs
		   		 if (!(Count_Samples&0xFFFF))
		   		 {
		   			LED_Data = (LED_Data << 1) | 0x01 ;	 	
		   		    XIo_Out32(XPAR_LEDS_8BIT_BASEADDR, LED_Data);
		   		 }
			}
			xil_printf("\r\nPlayed %d samples on two channels", Count_Samples);
			LCDClear();
		    LCDPrintString   ("-     Play     -",
		    				  "-     Ended    -");
			break;
   		}
	 }
	 sw_data_pre = sw_data;
    }


   XCACHE_DISABLE_ICACHE();
   XCACHE_DISABLE_DCACHE();
   return 0;
}

/*****************************************************************************
*
* This function initializes the LCD screen and prints a text on it
*
* @param    First_Line, Second_Line are pointers to the strings to be printed
*           on the LCD screen
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDInitAndPrint (char * First_Line, char * Second_Line)
{

   LCDOff();
   LCDClear();
   LCDOn();
   LCDInit();
   LCDPrintString   (First_Line, Second_Line);	
	
}




