/*
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A 
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR 
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION 
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE 
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO 
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO 
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE 
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 */

/*****************************************************************************/
/**
*
* @Project LCD_Demo
* 
* Ported from Xilinx ML50X LCD demo
*
* This project contains an LCD display example to test the 2*16 character
* LCD display. Characters typed in the terminal are displayed on the LCD display
* Sending the TAB character (0x09) changes the LCD line. Sending the BACKSPACE
* character (0x08) clears the LCD display
* @note
*
* None
* 
******************************************************************************/

#define UART_BASEADDR  XPAR_RS232_UART_0_BASEADDR


#include <stdio.h>
#include "xparameters.h"
#include "xenv_standalone.h"
#include "xbasic_types.h"
#include "xgpio.h"
#include "xuartns550_l.h"
#include "sleep.h"
#include "lcd.h"

/******************************************************************************
 * 
 * 	Variable declaration
 * 
 * ***************************************************************************/
   
   //LCD globals
   u8 LCD_FirstPrint;
   u8 LCD_LinePos[2];
   u8 * LCD_CurrentLinePos;
   u8 LCD_CurrentLine;


/******************************************************************************
 * 
 * 	Function prototypes
 * 
 * ***************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine);
void LCDInitAndPrint (char * First_Line, char * Second_Line);

int main()
{
    char c;

   /* Initialize RS232_Uart_0 - Set baudrate and number of stop bits */
   XUartNs550_SetBaud(XPAR_RS232_UART_0_BASEADDR, XPAR_XUARTNS550_CLOCK_HZ, 9600);
   XUartNs550_mSetLineControlReg(XPAR_RS232_UART_0_BASEADDR, XUN_LCR_8_DATA_BITS);


   XCACHE_ENABLE_ICACHE();
   XCACHE_ENABLE_DCACHE();

   //initialize LCD
   LCDInitAndPrint ((char *) &"-    GENESYS   -", (char *) &"-  LCD   Demo  -");

    printf("\r\nYou should see your letters appear on the LCD as you type\r\n");
    printf("Press TAB (0x09) to move from between Line1 and Line2\r\n");
    printf("Press BACKSPACE (0x08) to clear the LCD\r\n");

   //initialize LCD globals
   LCD_FirstPrint = 1;
   LCD_LinePos[0] = 0;
   LCD_LinePos[1] = 0;
   LCD_CurrentLinePos = LCD_LinePos;
   LCD_CurrentLine = 0;



    while (1)
    {
         c = XUartNs550_RecvByte(XPAR_RS232_UART_0_BASEADDR);
         switch(c)
	 	{
             case 0x9: //Change the LCD line
                   LCD_CurrentLine = !LCD_CurrentLine;
                   LCDSetLine(LCD_CurrentLine + 1);
			       LCD_LinePos[LCD_CurrentLine]=0;
                   break;
             case 0x8: //Clear LCD display
                   LCD_CurrentLine = 0;
                   LCDClear();
                   break;
             default:
		            // clear the LCD display at the first printable character received 
		            // and enable cursor blink
		            LCDPrintandShift(c, &LCD_FirstPrint, LCD_CurrentLinePos, &LCD_CurrentLine);
                   break;
         }
    }


   XCACHE_DISABLE_ICACHE();
   XCACHE_DISABLE_DCACHE();
   return 0;
}

/*****************************************************************************
*
* This function prints a character on the LCD screen. At the first character printed
* the LCD screen is cleared and cursor blink is enabled. If the number of characters
* already printed on the LCD screen is larger than 16, the screen is shifted to the 
* left. If the number of characters already printed on a line is larger than 40 
* i.e. the current line is full, the LCD is set on the next line and the cursor is 
* moved to the beginning. 
*
* @param    c 			is the character to be printed
* 			FirstPrint 	is a pointer to a variable that shows whether a character was
*						previously printed or not
* 			LinePos		is a pointer to a u8 array of two, each element indicating the 
* 						current character position in the array
* 			CurrentLine is a poiter to a variable that represents the current LCD line
* 						(0 - first line, 1 - second line)
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine)
{

u8 * CharPos;

	
	CharPos = LCD_LinePos + (*CurrentLine);

		if (*FirstPrint)
		{
		  *FirstPrint = 0;
		  LCDClear();
		  LCDEnableCursorBlink();
		}
         (*CharPos)++;
    	 if (*CharPos <= 15 )
		 LCDPrintChar(c);
         //shift the LCD display if the number of displayed characters is larger than 16
         else if (*CharPos <= 40)
		 {
	       	LCDPrintChar(c);
            LCDEnableDisplayShift();
		 }
		 else//change the line and disable display shift if the current line is full
		 {
		  	*CharPos=0;
		    * CurrentLine = ! (* CurrentLine);
	    	LCDSetLine((*CurrentLine)+1);
	    	CharPos = LinePos + (*CurrentLine);
	    	*CharPos=1;
	    	LCDDisableDisplayShift();
	    	LCDPrintChar(c);
		 }
}

/*****************************************************************************
*
* This function initializes the LCD screen and prints a text on it
*
* @param    First_Line, Second_Line are pointers to the strings to be printed
*           on the LCD screen
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDInitAndPrint (char * First_Line, char * Second_Line)
{

   LCDOff();
   LCDClear();
   LCDOn();
   LCDInit();
   LCDPrintString   (First_Line, Second_Line);	
	
}




