/*
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A 
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR 
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION 
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE 
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO 
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO 
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE 
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 */

/*****************************************************************************/
/**
*
* @Project PS2_Demo
* 
* This project contains a PS2 demo example to show some of the PS2 core features.
* The application automatically detects whether a mouse or a keyboard is connected 
* to the PS2 connector. 
* If a keyboard is detected, the alphanumeric key characters are displayed on both
* the terminal and LCD screen. Left and right shift presses are also handled, 
* displaying capital letters if the shift key is pressed and an alphabetic key 
* is pressed.
* If a PS2 mouse is detected, the mouse is initialized the mouse data: Left, Right 
* and Mid button status and the mouse X and Y coordinates are displayed on both the 
* terminal and the LCD screen.
*
* @note
* The application is intended to work with standard PS2 devices
* 
******************************************************************************/

#define UART_BASEADDR  XPAR_RS232_UART_0_BASEADDR

#define PS2_DEVICE_BASEADDR XPAR_PS2_CONN_0_BASEADDR
#define PS2_PORT_1_RESET_OFFSET 0
#define PS2_PORT_1_STATUS_OFFSET 0x04
#define PS2_PORT_1_RX_OFFSET 0x08
#define PS2_PORT_1_TX_OFFSET 0x0C
#define PS2_RX_FULL 0
#define PS2_TX_FULL 1

#define PS2_ACK 0xFA

#include <stdio.h>
#include <string.h>
#include "xparameters.h"
#include "xenv_standalone.h"
#include "xbasic_types.h"
#include "xgpio.h"
#include "sleep.h"
#include "xuartns550_l.h"
#include "lcd.h"
#include "xintc.h"
#include "ps2_scan_code_map.h"


/******************************************************************************
 * 
 * 	Variable declaration
 * 
 * ***************************************************************************/

//set to 1 in order to display debug messages
unsigned char verbose=0;

	//LCD globals
	u8 LCD_FirstPrint;
	u8 LCD_LinePos[2];
	u8 * LCD_CurrentLinePos;
	u8 LCD_CurrentLine;

//variable showing whether or not a make code was sent from the keyboard
u8 make;
//variable showing whether or not the shift key were pressed on the keyboard
u8 shift;

//Mouse coordinate variables
int MouseX; 
int MouseY;


/******************************************************************************
 * 
 * 	Function prototypes
 * 
 * ***************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine);
void LCDInitAndPrint (char * First_Line, char * Second_Line);
char * ItoAsc (int num, char * res_string);
Xuint32 PS2_Recvbyte(Xuint32 PS2_BASEADDR, u8 * BuffPtr);
Xuint32 PS2_Sendbyte (Xuint32 PS2_BASEADDR, u8 PS2_Data);
Xuint32 Detect_PS2_Device (Xuint32 PS2_BASEADDR);
Xuint32 Initialize_PS2_Mouse (Xuint32 PS2_BASEADDR);
void DecodeAndDisplayKeyboardData (u8 PS2_Data, u8 * BufferPtr_Pre);
void DecodeAndDisplayMouseData(u8 * BufferPtr);

int main()
{
   Xuint32 i, j;
   u8 PS2_Data;
   XStatus Status;
   u8 Detected_Keyboard; //1 if keyboard, 0 if mouse
   //circular buffer and pointers
   u8 PS2_Data_Buffer[8];
   u8 * BuffPtr;
   u8 * BuffPtr_Pre;
   char c;

   /* Initialize RS232_Uart_0 - Set baudrate and number of stop bits */
   XUartNs550_SetBaud(XPAR_RS232_UART_0_BASEADDR, XPAR_XUARTNS550_CLOCK_HZ, 9600);
   XUartNs550_mSetLineControlReg(XPAR_RS232_UART_0_BASEADDR, XUN_LCR_8_DATA_BITS);


   XCACHE_ENABLE_ICACHE();
   XCACHE_ENABLE_DCACHE();
	
   //initialize LCD
   LCDInitAndPrint ((char *) "-  PS2  Demo   -", (char *)"");


   xil_printf ("\r\nPS2 Demo");

   //initialize LCD globals
   LCD_FirstPrint = 1;
   LCD_LinePos[0] = 0;
   LCD_LinePos[1] = 0;
   LCD_CurrentLinePos = LCD_LinePos;
   LCD_CurrentLine = 0;

   //initialize circular buffer pointers
   BuffPtr = PS2_Data_Buffer;
   BuffPtr_Pre = PS2_Data_Buffer + 4;

   //reset PS2 core
   XIo_Out32(PS2_DEVICE_BASEADDR + PS2_PORT_1_RESET_OFFSET, 0x0A); 

   xil_printf("\r\nDetecting PS2 Device, it takes about 5 seconds");
   Status = Detect_PS2_Device (PS2_DEVICE_BASEADDR);
   if (Status == 2)
   {
   		xil_printf("\r\nno PS2 device was detected. Please check the connections");
		LCDClear();
		LCDPrintString   ("-  PS2 Device   -",
    				      "  Not Detected   ");
   		return 1;
   }
   else if (Status == 3)
   {
   		xil_printf("\r\nPS2 communication error. Please check the connections");
		LCDClear();
		LCDPrintString   ("PS2 Communication",
    				      "     Error       ");
   		return 1;	
   }
   else if (Status == 1)
   {
		xil_printf ("\r\nPS2 Keyboard Detected");
		LCDClear();
		LCDPrintString   ("- PS2 Keyboard -",
    				      "    Detected    ");
		Detected_Keyboard = 1;
		
		xil_printf("\r\nKeyboard alphanumeric keys will be displayed");
		xil_printf("\r\non the terminal and on the LCD screen");
		xil_printf("\r\nthe Shift key is also handled for alphabetic characters\r\n");
	}
	else //if the received byte is 0 then mouse is detected
	{
			xil_printf ("\r\nPS2 Mouse Detected");
			LCDClear();
			LCDPrintString   ("-  PS2  Mouse  -",
	    				      "    Detected    ");
			Detected_Keyboard = 0;
			Status = Initialize_PS2_Mouse (PS2_DEVICE_BASEADDR);

		   if (Status)
		   { 
		   	 xil_printf ("\r\nMouse Initialization Error");
		   	 xil_printf ("\r\nChange the mouse and check connections, then try again");
		   	 return 1;
		   }
		   
		   xil_printf("\r\nMouse Initialization Successfull\r\n");
		   xil_printf("\r\nMouse data such as Left, Right, Mid button status");
		   xil_printf("\r\nand Mouse coordinates will be displayed");
		   xil_printf("\r\n on the terminal and the LCD screen\r\n");
		   //initialize mouse coordinates
		   MouseX = 0; 
		   MouseY = 0;
	}

    //initialize buffer and index
    for (i=0; i<5; i++) PS2_Data_Buffer[i] = 0;
    i = 0;
    make = 0;
	while (1)
	{
		if (Detected_Keyboard)
		{
		  //if data is received 
		  if (((XIo_In32(PS2_DEVICE_BASEADDR + PS2_PORT_1_STATUS_OFFSET)) & (1 << PS2_RX_FULL)))
		  {
		   	PS2_Data= XIo_In32 (PS2_DEVICE_BASEADDR + PS2_PORT_1_RX_OFFSET);

			//decode and display the data if valid scancode were received
			DecodeAndDisplayKeyboardData (PS2_Data, BuffPtr_Pre);

			//save data in the circular buffer and update the pointers
			*BuffPtr = PS2_Data;
			BuffPtr_Pre = BuffPtr;
			if (BuffPtr == (PS2_Data_Buffer +4))
			   BuffPtr = PS2_Data_Buffer;
			else
			   BuffPtr++;	
		  }				
		}
		else//mouse detected
		{
		  //Read 3 bytes from the mouse, then display the mouse data
		  if (((XIo_In32(PS2_DEVICE_BASEADDR + PS2_PORT_1_STATUS_OFFSET)) & (1 << PS2_RX_FULL)))
		  {
		  	*BuffPtr = XIo_In32 (PS2_DEVICE_BASEADDR + PS2_PORT_1_RX_OFFSET);
			BuffPtr++;
			i++;
			if (i==3)
			{ 
			  i = 0;
			  BuffPtr = PS2_Data_Buffer;
			  DecodeAndDisplayMouseData(BuffPtr);
			}
		  }				
		}
	}

   XCACHE_DISABLE_ICACHE();
   XCACHE_DISABLE_DCACHE();
   return 0;
}

/*****************************************************************************
*
* This function prints a character on the LCD screen. At the first character printed
* the LCD screen is cleared and cursor blink is enabled. If the number of characters
* already printed on the LCD screen is larger than 16, the screen is shifted to the 
* left. If the number of characters already printed on a line is larger than 40 
* i.e. the current line is full, the LCD is set on the next line and the cursor is 
* moved to the beginning. 
*
* @param    c 			is the character to be printed
* 			FirstPrint 	is a pointer to a variable that shows whether a character was
*						previously printed or not
* 			LinePos		is a pointer to a u8 array of two, each element indicating the 
* 						current character position in the array
* 			CurrentLine is a poiter to a variable that represents the current LCD line
* 						(0 - first line, 1 - second line)
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine)
{

u8 * CharPos;

	
	CharPos = LCD_LinePos + (*CurrentLine);

		if (*FirstPrint)
		{
		  *FirstPrint = 0;
		  LCDClear();
		  LCDEnableCursorBlink();
		}
         (*CharPos)++;
    	 if (*CharPos <= 15 )
		 LCDPrintChar(c);
         //shift the LCD display if the number of displayed characters is larger than 16
         else if (*CharPos <= 40)
		 {
	       	LCDPrintChar(c);
            LCDEnableDisplayShift();
		 }
		 else//change the line and disable display shift if the current line is full
		 {
		  	*CharPos=0;
		    * CurrentLine = ! (* CurrentLine);
	    	LCDSetLine((*CurrentLine)+1);
	    	CharPos = LinePos + (*CurrentLine);
	    	*CharPos=1;
	    	LCDDisableDisplayShift();
	    	LCDPrintChar(c);
		 }
}

/*****************************************************************************
*
* This function initializes the LCD screen and prints a text on it
*
* @param    First_Line, Second_Line are pointers to the strings to be printed
*           on the LCD screen
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDInitAndPrint (char * First_Line, char * Second_Line)
{

   LCDOff();
   LCDClear();
   LCDOn();
   LCDInit();
   LCDPrintString   (First_Line, Second_Line);	
	
}

/*****************************************************************************
*
* This function converts a 16-bit integer number into an ASCII string in decimal
* format. Leading zeroes are trimmed from the string
*
* @param    num			is the integer number that is converted
*           res_string	is a pointer to the resulting character string
* 						At least 7 characters should be reserved for 
* 						the string (sign character, in case, five digits 
* 						and the \0 character)
* 
* @return   A pointer to the beginning of the string (same as the
* 			res_string pointer)
*
* @note     None
*
******************************************************************************/

char * ItoAsc (int num, char * res_string)
{
char * resptr;
int i;
int q, rem;
int divrate = 10000;
char c;

 resptr = res_string;
	
if (num == 0)
{
  *resptr = 0x30;
  resptr++;
  *resptr = 0;	
}	
else
{
  if (num<0)
  { 
	*resptr = '-';
	resptr++;
    num = abs (num);
   }

   //trim leading zeroes
   while (!(num/divrate))
   {
  	  num = num % divrate;
  	  divrate = divrate / 10;
    }
 
    while (divrate >0)
    {
	  q = num / divrate;
	  rem = num % divrate;
	  divrate = divrate / 10;
	  *resptr = 0x30 | q ;
	  resptr++;
	  num = rem;
	}
  *resptr = 0;
} 	

 resptr = res_string;
 return res_string;
}

/*****************************************************************************
*
* This function receives a byte from the PS2 device. The function implements timeout
* of about 1S long. In the case of timeout the function returns 1
*
* @param    PS2_BASEADDR	is the base address of the PS2 core
*           BuffPtr 		is a pointer to a u8 variable or buffer where the
* 							received byte is stored
* 
* @return   1 if timeout
* 			0 if a byte was received
*
* @note     None
*
******************************************************************************/

Xuint32 PS2_RecvByte(Xuint32 PS2_BASEADDR, u8 * BuffPtr)
{
Xuint32 i;
u8 PS2_Data;

 i=0;
   while (!((XIo_In32(PS2_BASEADDR + PS2_PORT_1_STATUS_OFFSET)) & (1 << PS2_RX_FULL)))
   {
   		i++;
         usleep (500);
   		if (i==1000)
   		{
   			 if (verbose) xil_printf("\r\nReceive Timeout");
   			 return 1;
   		}
   }
  
   PS2_Data = XIo_In32 (PS2_BASEADDR + PS2_PORT_1_RX_OFFSET);
   * BuffPtr = PS2_Data;
   return 0;		
}

/*****************************************************************************
*
* This function sends a byte to the PS2 device. The function implements timeout
* of about 1S long. In the case of timeout the function returns 1 
*
* @param    PS2_BASEADDR	is the base address of the PS2 core
*           PS2_Data 		is the byte to be sent
* 
* @return   1 if timeout
* 			0 if a byte was received
*
* @note     None
*
******************************************************************************/

Xuint32 PS2_SendByte (Xuint32 PS2_BASEADDR, u8 PS2_Data)
{
Xuint32 i;

  XIo_Out32(PS2_BASEADDR + PS2_PORT_1_TX_OFFSET, PS2_Data);
 i=0;
 while ((XIo_In32(PS2_BASEADDR + PS2_PORT_1_STATUS_OFFSET)) & (1 << PS2_TX_FULL))
   {
   		i++;
        usleep (500);
   		if (i==1000) return 1;
   }
   return 0;		
}

/*****************************************************************************
*
* This function detects the type of the PS2 device. The function first resets 
* the PS2 device (by sending 0xFF), receives the response bytes, then sends the
* "Get Device ID" (0xF2) command. If there is no byte received after acknowledge 
* (0xFA) or the received byte is 0, then the detected device is mouse, otherwise
* keyboard.
* Because the number of bytes send by the PS2 device depends on the type of 
* the PS2 keyboard or mouse, the function uses the "PS2_RecvByte" function until
* timeout is encountered. Therefore due to the timeout, detecting the type
* of the PS2 device can take up to 5S.
*
* @param    PS2_BASEADDR	is the base address of the PS2 core

* 
* @return   0 if mouse is detected
* 			1 if keyboard were detected
* 			2 if the device is not answering i.e. it was not detected
* 			3 if commuinication error was encountered, for example no acknowledge 
* 			  or error byte is received
*
* @note     None
*
******************************************************************************/

Xuint32 Detect_PS2_Device (Xuint32 PS2_BASEADDR)
{
u8 i;
u8 PS2_Data;
u8 PS2_Data_Buffer[4];
u8 * BuffPtr;
XStatus Status;

	//initialize data buffer
	for (i=0; i<4; i++) PS2_Data_Buffer[i] = 0;
	
	BuffPtr = PS2_Data_Buffer;
   //send reset to the PS2 device
   Status = PS2_SendByte (PS2_BASEADDR, 0xFF);
	if (Status) return 2;
   
   //Attempt to receive acknowledge from the PS2 device
   Status = PS2_RecvByte(PS2_BASEADDR, BuffPtr);
   if (Status) return 2;
   if ( *BuffPtr != PS2_ACK) return 3;
   
   //attempt to receive the self-test and ID bytes
   do
   { 
   	Status = PS2_RecvByte(PS2_BASEADDR, BuffPtr);
   	if (verbose) xil_printf("\r\nStatus = 0x%X", Status);
   }
   while (!(Status));
   
   //send Device ID command and wait for answer
   if (verbose) xil_printf ("\r\nSending Device ID command");
   Status = PS2_SendByte (PS2_BASEADDR, 0xF2);
   
   do
   {
   	Status = PS2_RecvByte(PS2_BASEADDR, BuffPtr);
   	if (verbose) xil_printf("\r\nStatus = 0x%X, data received = 0x%X", Status, *BuffPtr);
   	BuffPtr++;
   }
   while (!(Status));

   //seek in the buffer for the acknowledge byte
   for (i=0; i<4; i++)
   {
   	 if (verbose) xil_printf("\r\nPS2_Data_Buffer[%d] = 0x%X", i, PS2_Data_Buffer[i]);
  	 if  (PS2_Data_Buffer[i] == PS2_ACK) break;
   }
   //if PS2 acknowledge was not found then communication error
   if (i==3) return 3;

   //check the byte received after the acknowledge
   BuffPtr = PS2_Data_Buffer + i + 1;
   if (verbose) xil_printf("\r\nData received after acknowledge = 0x%X", *BuffPtr);
   if (*BuffPtr == 0x00)
   {
   	 return 0; //mouse detected
   }
   else if (*BuffPtr == 0xFC)
   {
   	 return 3;
   }
   else return 1; //keyboard detected
}

/*****************************************************************************
*
* This function initializes a the PS2 mouse. It assumes that the mouse is in 
* PS2 standard mode, no IntelliMouse extensinons are used. First the default 
* values are set (refresh rate:100 samples per second, 1:1 scaling, 4 counts/mm
* resolution, data reporting disabled) by sending 0xF6 to the device 
* Because mouse data is displayed both on the terminal and the LCD screen, in 
* order to not loose bytes from the mouse the refresh rate is reduced to the minimum
* i.e. 10 samples/seconds. The resolution is also reeduced to 1 count/mm.
* After the refresh rate is set the Enable Data Reporting command is set (0xF4)
* to the device 
*
* @param    PS2_BASEADDR	is the base address of the PS2 core

* 
* @return   0 if mouse initialization is successfull
* 			1 if initialization error, for example no acknowledge byte is received 
* 			  from the mouse
*
* @note     None
*
******************************************************************************/

Xuint32 Initialize_PS2_Mouse (Xuint32 PS2_BASEADDR)
{
//returns 0 if initialization successfull
//returns 1 if initialization error
XStatus Status;
u8 Data;

   //set defaults for the mouse
   Status = PS2_SendByte (PS2_BASEADDR, 0xF6);
   if (Status) return 1;
   
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;

   
   //Send set sample rate command to the mouse
   Status = PS2_SendByte (PS2_BASEADDR, 0xF3);
   if (Status) return 1;
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;
   

   //Set sample rate to 10 
   Status = PS2_SendByte (PS2_BASEADDR, 0x0A);
   if (Status) return 1;
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;
   

   //Send set resolution command to the mouse
   Status = PS2_SendByte (PS2_BASEADDR, 0xE8);
   if (Status) return 1;
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;
   
   //set resolution to 1 count/mm
   Status = PS2_SendByte (PS2_BASEADDR, 0x00);
   if (Status) return 1;
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;

   //Enable data reporting for the mouse
   Status = PS2_SendByte (PS2_BASEADDR, 0xF4);
   if (Status) return 1;
   //wait for acknowledge
   Status = PS2_RecvByte(PS2_BASEADDR, &Data);
   if (Status) return 1;
   if (Data != PS2_ACK) return 1;
   
   return 0;

}

/*****************************************************************************
*
* This function decodes a byte received from the keyboard. If a scan code
* is found that corresponds to an alphanumeric character it is displayed on the
* terminal and the LCD screen.
* In the main program the data received from the keyboard is stored in a circular
* buffer, therefore the function is able to filter out the extended scan codes
* (0xE0 followed by the scan code) and the break and extended break codes (0xF0
* followed by the scan code or 0xE0 0xF0, or 0xE0 0xF0 followed by the scan code)
* Keyboard Left shift and right shift presses are also handled. In the case if shift
* is pressed and an alphabetic scan code follows, the capita letter of the alphabetic
* code is displayed (ASCII code - 0x20)
* The scan code to ASCII table is stored in the ScanCodeMap[] array in the
* ps2_scan_code_map.h file. The scan code to ASCII table assumes that the keyboard uses
* Scan Code Set 2
*
* @param    PS2_Data 		is the last byte received from the keyboard to be decoded
*			BufferPtr_Pre	is a u8 pointer that points to the previously received byte
*							stored in the circular buffer where bytes received from 
*							the keyboard are stored
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void DecodeAndDisplayKeyboardData (u8 PS2_Data, u8 * BufferPtr_Pre)
{

char c;

  //check for shift released
  if (((PS2_Data == 0x12) || (PS2_Data == 0x59)) 
  	   && (*BufferPtr_Pre == 0xF0))
  {
    make = 0;
    shift = 0;
  }
  //check for shift pressed
  else if ((PS2_Data == 0x12) || (PS2_Data == 0x59))
  {
    make = 0;
	shift = 1;
  }
  //check and for extended scancodes and break codes
  if   ((PS2_Data == 0xE0) || (PS2_Data == 0xF0)
	    || (*BufferPtr_Pre == 0xE0) || (*BufferPtr_Pre == 0xF0))
  {
	make = 0;
  }
  else
  {
	make = 1;
  }

  //display the received make code
  if (make)
  {
    if (shift &&(ScanCodeMap[PS2_Data] >= 0x61) && (ScanCodeMap[PS2_Data] <= 0x7A))
    {
      //Display capital letters if Shift is pressed and the character code is alphabetic
      c = ScanCodeMap[PS2_Data] - 0x20;
    }
	else
	{
	  c = ScanCodeMap[PS2_Data];
    }				
    //display only the characters for which a valid ASCII code exists 
    //in the ScanCodeMap table
    if (c)
    {
	   XUartNs550_SendByte(UART_BASEADDR, c);
	   LCDPrintandShift(c, &LCD_FirstPrint, LCD_CurrentLinePos, &LCD_CurrentLine);

    }
  }

}

/*****************************************************************************
*
* This function decodes and displays on the terminal and the LCD screen the data 
* from the three bytes received from the mouse. It is assumed that the data sent 
* by the mouse is in standard PS2 three-byte format, no scrolling bar nor other 
* Intellimouse extensions are used
* The data decoded are:
* 	Left Button 		: Bit 0 of the first byte received
* 	Right button		: Bit 1 of the first byte received
* 	Mid button      	: Bit 2 of the first byte received
* 	Sign of X movement	: Bit 4 of the first byte received
* 	Sign of Y movement	: Bit 5 of the first byte received
* 	X movement overflow	: Bit 6 of the first byte received
* 	Y movement overflow	: Bit 7 of the first byte received
*	X movement			: Second byte received
*	Y movement			: Third byte received
* 
* The data displayed are the status of the Left, Right and Mid buttons and the 
* X and Y coordinates starting from 0 from the moment when the mouse is initialized
* 	
* 
* @param    BufferPtr	is a pointer to a three-byte buffer that stores the bytes
* 						received from the mouse
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void DecodeAndDisplayMouseData(u8 * BufferPtr)
{
   u8 i;
   
   u8 * BuffPtr;
   
   //String to store the integer number converted into 
   char Int_Ascii[7];
   char * IntAsc;
   
   //Mouse data. Mouse coordinates are stored in globals
   u8 Left, Right, Mid;
   u8 XSign, YSign;
   u8 XOvf, YOvf;
   
   //LCD message strings to be displayed
   char LCDLine0[16];
   char LCDLine1[16];
   char * LCDString;
   char * FormString;

   //Initialize the pointer to the ASCII string
   IntAsc = Int_Ascii;

   BuffPtr = BufferPtr;
   
   //determine mouse button status and movement sign
   Left = *BuffPtr & 0x01;
   Right = (*BuffPtr & 0x02) >> 1;
   Mid =   (*BuffPtr & 0x04) >> 2;
   XSign =  *BuffPtr & 0x10;
   YSign =  *BuffPtr & 0x20;
   XOvf =   *BuffPtr & 0x40;
   YOvf =   *BuffPtr & 0x80;
   
   //calculate actual mouse coordinates according to the movement, sign and overflow
   if (!XOvf)
   {
	   if (XSign) MouseX = MouseX - (257  - *(++BuffPtr));
	   else MouseX = MouseX + *(++BuffPtr);
   }
   else
   {
	   if (XSign) MouseX = MouseX - 256;
	   else MouseX = MouseX + 256;   	
   }
   
   if (!YOvf)
   {
	   if (YSign) MouseY = MouseY - (257  - *(++BuffPtr));
	   else MouseY = MouseY + *(++BuffPtr);
   }
   else
   {
	   if (YSign) MouseY = MouseY - 256;
	   else MouseY = MouseY + 256;
   }
	
   //print on the terminal the mouse data
   xil_printf("\rMouse L:%d, R:%d, M:%d, X:%3d, Y:%3d", Left, Right, Mid, MouseX, MouseY);
   
   //First LCD line format: "L: %d, R: %d, M: %d"
   for (i=0; i<16; i++) LCDLine0[i] = 0;
   LCDString = LCDLine0;
   FormString  = strcat (LCDString, (char *) &"L: ");
   FormString  = strcat (LCDString, ItoAsc (Left, IntAsc));
   FormString  = strcat (LCDString, (char *) &", R: ");
   FormString  = strcat (LCDString, ItoAsc (Right, IntAsc));
   FormString  = strcat (LCDString, (char *) &", M: ");
   FormString  = strcat (LCDString, ItoAsc (Mid, IntAsc));
				  
   //Second LCD line format: "X: %d, Y: %d"
   for (i=0; i<16; i++) LCDLine1[i] = 0;
   LCDString = LCDLine1;
   FormString  = strcat (LCDString, (char *) &" X:");
   FormString  = strcat (LCDString, ItoAsc (MouseX, IntAsc));
   FormString  = strcat (LCDString, (char *) &", Y:");
   FormString  = strcat (LCDString, ItoAsc (MouseY, IntAsc));
		  				  				  
   LCDClear();
   LCDPrintString   (LCDLine0, LCDLine1);
}







