/*
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A 
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR 
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION 
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE 
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO 
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO 
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE 
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 */

/*****************************************************************************/
/**
*
* @Project USB_HPI_Demo
* 
* Ported from Xilinx ML50X usb-hpi demo
*
* This project contains an USB keyboard example to test the Cypress CY7C67300
* USB controller in a host mode using the HPI interface. A standard USB keyboard
* (without a built-in hub) should be connected to the USB host port of the
* Genesys board.
*
* This example contains the software for the internal microprocessor
* inside the Cypress CY7C67300 USB controller. The FPGAs processor writes the
* data to the internal memory inside the USB controller through the HPI port.
* The USB controller's internal processor then starts and can begin implementing
* low-level USB commands to communicate with the USB keyboard. Data from the USB
* keyboard is transferred to the FPGAs processor using mailbox registers over
* the HPI port. Keys typed on the USB keyboard are displayed on both the 
* terminal and LCD display
*
* @note
*
* If the Cypress controller does not start, press the Reset button to reinitialize
* the USB controller
* 
******************************************************************************/

#define UART_BASEADDR  XPAR_RS232_UART_0_BASEADDR


#include <stdio.h>
#include "xparameters.h"
#include "usbkeyboardbin.h"
#include "xenv_standalone.h"
#include "xbasic_types.h"
#include "xgpio.h"
#include "xuartns550_l.h"
#include "sleep.h"
#include "usb_hpi.h"


/******************************************************************************
 * 
 * 	Variable declaration
 * 
 * ***************************************************************************/


static char UpperMap[] = {
    0,  0,  0,  0,'A','B','C','D',
  'E','F','G','H','I','J','K','L',
  'M','N','O','P','Q','R','S','T',
  'U','V','W','X','Y','Z','!','@',
  '#','$','%','^','&','*','(',')',
  '\n',27,'\b','\t',' ','_','+','{',
  '}','|','|',':','"','~','<','>',
  '?'
};

static char LowerMap[] = {
    0,  0,  0,  0,'a','b','c','d',
  'e','f','g','h','i','j','k','l',
  'm','n','o','p','q','r','s','t',
  'u','v','w','x','y','z','1','2',
  '3','4','5','6','7','8','9','0',
  '\n',27,'\b','\t',' ','-','=','[',
  ']','\\','\\',';','\'','`',',','.',
  '/'
};

static int OldLower = 0;

   //LCD globals
   u8 LCD_FirstPrint;
   u8 LCD_LinePos[2];
   u8 * LCD_CurrentLinePos;
   u8 LCD_CurrentLine;

/******************************************************************************
 * 
 * 	Function prototypes
 * 
 * ***************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine);
void LCDInitAndPrint (char * First_Line, char * Second_Line);

int main()
{
 
   Xuint32 TempData;
   Xuint32 i;
   Xuint16 TempData16;
   Xuint16 Temp;
   


   /* Initialize RS232_Uart_0 - Set baudrate and number of stop bits */
   XUartNs550_SetBaud(XPAR_RS232_UART_0_BASEADDR, XPAR_XUARTNS550_CLOCK_HZ, 9600);
   XUartNs550_mSetLineControlReg(XPAR_RS232_UART_0_BASEADDR, XUN_LCR_8_DATA_BITS);


   XCACHE_ENABLE_ICACHE();
   XCACHE_ENABLE_DCACHE();

   //initialize LCD
   LCDInitAndPrint ((char *) &"- GENESYS  USB -", (char *) &"-Keyboard Demo -");

   //initialize LCD globals
   LCD_FirstPrint = 1;
   LCD_LinePos[0] = 0;
   LCD_LinePos[1] = 0;
   LCD_CurrentLinePos = LCD_LinePos;
   LCD_CurrentLine = 0;



   //load the Cypress controller with the firmware
   UsbWriteBin(USB_BASE_ADDR);

   xil_printf("GENESYS USB Keyboard Demo\r\n\r\n");


   //initiate soft reset on the USB controller 
   UsbSoftReset();
   //wait until soft reset is done
   while (XIo_In16(USB_MAILBOX) != COMM_ACK){;}

  //Start the executable on the USB controller
   UsbSetPc(USB_BASE_ADDR);
   
   xil_printf("Please connect a USB Keyboard to the Genesys board.\r\n");
   xil_printf("Keypresses will appear on the UART terminal and the LCD screen.\r\n");
   xil_printf("The Enter key is also handled\r\n");
   xil_printf("Note: USB Keyboard must not have a built-in hub.\r\n\r\n");


	

 while (1)
    {
        /*
         * Read the contents of the mailbox register by polling the register
         */
        UsbReadMailbox();
    }


   XCACHE_DISABLE_ICACHE();
   XCACHE_DISABLE_DCACHE();
   return 0;
}




/*****************************************************************************/
/**
*
* This function puts the bin file for USB Keyboard test into the internal memory
* of USB chip through the HPI interface.
*
* @param    UsbBaseAddress is the starting location of the USB internal memory
*           to which this bin file data is written.
*
* @return   None
*
* @note     None
*
******************************************************************************/
void UsbWriteBin(Xuint16 UsbBaseAddress)
{
    Xuint32 Index;
    Xuint16 Temp16;
    Xuint8 char0, char1;

    xil_printf("Loading executable file for USB controller chip.\r\n\r\n");
    XIo_Out16(USB_ADDRESS, UsbBaseAddress);
    for (Index = 0; Index < 0x2E9D; Index+=2)
    {
        Temp16 = 0;
	char0 = KeyboardBin[Index]; 
	char1 = KeyboardBin[Index+1]; 
        Temp16 = (char1 << 8) | char0; 
        XIo_Out16(USB_DATA, Temp16);
      //XIo_Out16(USB_DATA, (KeyboardBin[Index+1] << 8) | KeyboardBin[Index]);
    }
}

/*****************************************************************************/
/**
*
* This function does a software reset of the Cypress CY7C67300 USB controller.
*
* @param    UsbBaseAddress is the starting location of the USB internal memory
*           to which this bin file data is written.
*
* @return   None
*
* @note     None
*
******************************************************************************/
void UsbSoftReset()
{
    XIo_Out16(USB_MAILBOX, COMM_RESET);
}

/*****************************************************************************/
/**
*
* This function sets the program counter of the internal processor of
* Cypress CY7C67300 USB controller and the code starts executing from that
* address.
*
* @param    UsbAddress is the starting location of the bin file data.
*
* @return   None
*
* @note     None
*
******************************************************************************/
void UsbSetPc(Xuint16 UsbAddress)
{
    /*
     * Set COMM_CODE_ADDR to addr
     */
    UsbWrite(COMM_CODE_ADDR, UsbAddress);

    /*
     * Set MailBox to execute command
     */
    XIo_Out16(USB_MAILBOX, COMM_JUMP2CODE);
}

/*****************************************************************************/
/**
* This function reads the Cypress CY7C67300 USB controller's mailbox register
* and outputs the keyboard presses to the UART terminal.
*
* @param    None
*
* @return   None
*
* @note     None
*
******************************************************************************/
void UsbReadMailbox()
{
    Xuint16 Status;
    Xuint16 MailboxData;
    Xuint16 Modifier;


    Status = XIo_In16(USB_STATUS);
	//xil_printf ("\r\nStatus = 0x%X", Status);

    if (Status & 0x001)
    {
        MailboxData = XIo_In16(USB_MAILBOX);		
        Modifier = MailboxData >> 8;
        MailboxData = MailboxData & 0x00FF;
        if (OldLower != MailboxData)
        {
            if (Modifier & 0x0022)
            {	
                if (MailboxData >= 4 && MailboxData <= 56)
                {
					XUartNs550_SendByte(UART_BASEADDR, UpperMap[MailboxData]);
                    //do not print on LCD the \n char
                    if (MailboxData != 40)
                    {
	                  LCDPrintandShift(UpperMap[MailboxData], &LCD_FirstPrint, LCD_CurrentLinePos, &LCD_CurrentLine);
                    }
                }
                if (MailboxData == 40)
                {
                    XUartNs550_SendByte(UART_BASEADDR, '\r');
                    LCD_CurrentLine = !LCD_CurrentLine; //Change the LCD line
                    LCDSetLine(LCD_CurrentLine+1);
                    LCDDisableDisplayShift(); //disable the shift at the beginnig of the line
                    LCD_LinePos[LCD_CurrentLine]=0; //reset the current position counter
                }
            }
            else
            {
                if (MailboxData >= 4 && MailboxData <= 56)
                {
                    XUartNs550_SendByte(UART_BASEADDR, LowerMap[MailboxData]);
                    //do not print on LCD the \n char
                    if (MailboxData != 40)
                    {
					  LCDPrintandShift(LowerMap[MailboxData], &LCD_FirstPrint, LCD_CurrentLinePos, &LCD_CurrentLine);
                    }
                }
                if (MailboxData == 40)
                {
                    XUartNs550_SendByte(UART_BASEADDR, '\r');
                   	LCD_CurrentLine = !LCD_CurrentLine; //Change the LCD line
                    LCDSetLine(LCD_CurrentLine);
                    LCDDisableDisplayShift(); //disable the shift at the beginnig of the line
                    LCD_LinePos[LCD_CurrentLine]=0; //reset the current position counter
                }
            }
            OldLower = MailboxData;
        }

    }

}


/*****************************************************************************
*
* This function writes data to the internal registers of the Cypress
* CY7C67300 USB controller.
*
* @param    Address is the address of the register.
* @param    Data is the data to be written to the register.
*
* @return   None
*
* @note     None
*
******************************************************************************/
void UsbWrite(Xuint16 Address, Xuint16 Data)
{
    XIo_Out16(USB_ADDRESS, Address);
    XIo_Out16(USB_DATA, Data);
}

/*****************************************************************************
*
* This function reads data from the internal registers of the Cypress
* CY7C67300 USB controller.
*
* @param    Address is the address of the register.
*
* @return   The data read from the specified address
*
* @note     None
*
******************************************************************************/
Xuint16 UsbRead(Xuint16 Address)
{
    XIo_Out16(USB_ADDRESS, Address);
    return XIo_In16(USB_DATA);
}

/*****************************************************************************
*
* This function prints a character on the LCD screen. At the first character printed
* the LCD screen is cleared and cursor blink is enabled. If the number of characters
* already printed on the LCD screen is larger than 16, the screen is shifted to the 
* left. If the number of characters already printed on a line is larger than 40 
* i.e. the current line is full, the LCD is set on the next line and the cursor is 
* moved to the beginning. 
*
* @param    c 			is the character to be printed
* 			FirstPrint 	is a pointer to a variable that shows whether a character was
*						previously printed or not
* 			LinePos		is a pointer to a u8 array of two, each element indicating the 
* 						current character position in the array
* 			CurrentLine is a poiter to a variable that represents the current LCD line
* 						(0 - first line, 1 - second line)
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDPrintandShift(char c, u8 * FirstPrint, u8 * LinePos, u8 * CurrentLine)
{

u8 * CharPos;

	
	CharPos = LCD_LinePos + (*CurrentLine);

		if (*FirstPrint)
		{
		  *FirstPrint = 0;
		  LCDClear();
		  LCDEnableCursorBlink();
		}
         (*CharPos)++;
    	 if (*CharPos <= 15 )
		 LCDPrintChar(c);
         //shift the LCD display if the number of displayed characters is larger than 16
         else if (*CharPos <= 40)
		 {
	       	LCDPrintChar(c);
            LCDEnableDisplayShift();
		 }
		 else//change the line and disable display shift if the current line is full
		 {
		  	*CharPos=0;
		    * CurrentLine = ! (* CurrentLine);
	    	LCDSetLine((*CurrentLine)+1);
	    	CharPos = LinePos + (*CurrentLine);
	    	*CharPos=1;
	    	LCDDisableDisplayShift();
	    	LCDPrintChar(c);
		 }
}

/*****************************************************************************
*
* This function initializes the LCD screen and prints a text on it
*
* @param    First_Line, Second_Line are pointers to the strings to be printed
*           on the LCD screen
* 
* @return   None
*
* @note     None
*
******************************************************************************/

void LCDInitAndPrint (char * First_Line, char * Second_Line)
{

   LCDOff();
   LCDClear();
   LCDOn();
   LCDInit();
   LCDPrintString   (First_Line, Second_Line);	
	
}
